@@ -247,7 +247,7 @@ class SqliteSession : Sqlite
 		 * */
 		
 		//select persons of each session
-		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.PersonSessionWeightTable + 
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.PersonSessionTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -518,7 +518,7 @@ class SqliteSession : Sqlite
 	}
 
 	
-	public static void DeleteWithJumps(string uniqueID)
+	public static void DeleteAllStuff(string uniqueID)
 	{
 		dbcon.Open();
 
@@ -527,8 +527,10 @@ class SqliteSession : Sqlite
 		dbcmd.ExecuteNonQuery();
 		
 		//delete relations (existance) within persons and sessions in this session
-		dbcmd.CommandText = "Delete FROM " + Constants.PersonSessionWeightTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.PersonSessionTable + " WHERE sessionID == " + uniqueID;
 		dbcmd.ExecuteNonQuery();
+
+		Sqlite.deleteOrphanedPersons();
 		
 		//delete normal jumps
 		dbcmd.CommandText = "Delete FROM " + Constants.JumpTable + " WHERE sessionID == " + uniqueID;
@@ -538,87 +540,30 @@ class SqliteSession : Sqlite
 		dbcmd.CommandText = "Delete FROM " + Constants.JumpRjTable + " WHERE sessionID == " + uniqueID;
 		dbcmd.ExecuteNonQuery();
 		
-		//runs PENDING
+		//delete normal runs
+		dbcmd.CommandText = "Delete FROM " + Constants.RunTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.ExecuteNonQuery();
+		
+		//delete intervallic runs
+		dbcmd.CommandText = "Delete FROM " + Constants.RunIntervalTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.ExecuteNonQuery();
+		
+		//delete reaction times
+		dbcmd.CommandText = "Delete FROM " + Constants.ReactionTimeTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.ExecuteNonQuery();
+		
+		//delete pulses
+		dbcmd.CommandText = "Delete FROM " + Constants.PulseTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.ExecuteNonQuery();
+		
+		//delete multiChronopic
+		dbcmd.CommandText = "Delete FROM " + Constants.MultiChronopicTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.ExecuteNonQuery();
+		
 		
 		dbcon.Close();
 	}
 
-
-	/* OLD STUFF */
-
-	/* 
-	 * don't do more like this, use Sqlite.convertTables()
-	 */
-	//change DB from 0.55 to 0.56
-	protected internal static void convertTableAddingSportStuff() 
-	{
-		ArrayList myArray = new ArrayList(2);
-
-		//1st create a temp table
-		//createTable(Constants.ConvertTempTable);
-		SqliteSession sqliteSessionObject = new SqliteSession();
-		sqliteSessionObject.createTable(Constants.ConvertTempTable);
-			
-		//2nd copy all data from session table to temp table
-		dbcmd.CommandText = "SELECT * " + 
-			"FROM " + Constants.SessionTable + " ORDER BY uniqueID"; 
-		SqliteDataReader reader;
-		reader = dbcmd.ExecuteReader();
-		while(reader.Read()) {
-			Session mySession = new Session(reader[0].ToString(), reader[1].ToString(), 
-					reader[2].ToString(), UtilDate.FromSql(reader[3].ToString()), 
-					1, //sport undefined
-					-1, //speciallity undefined
-					-1, //practice level undefined
-					reader[4].ToString(), //comments
-					Constants.ServerUndefinedID
-					); 
-			myArray.Add(mySession);
-		}
-		reader.Close();
-
-		foreach (Session mySession in myArray)
-			InsertOld(true, Constants.ConvertTempTable,
-				mySession.Name, mySession.Place, UtilDate.ToSql(mySession.Date), 
-				mySession.PersonsSportID, mySession.PersonsSpeciallityID, mySession.PersonsPractice, mySession.Comments);
-
-		//3rd drop table sessions
-		Sqlite.dropTable(Constants.SessionTable);
-
-		//4d create table persons (now with sport related stuff
-		//createTable(Constants.SessionTable);
-		sqliteSessionObject.createTable(Constants.SessionTable);
-
-		//5th insert data in sessions (with sport related stuff)
-		foreach (Session mySession in myArray) 
-			InsertOld(true, Constants.SessionTable,
-				mySession.Name, mySession.Place, UtilDate.ToSql(mySession.Date), 
-				mySession.PersonsSportID, mySession.PersonsSpeciallityID, mySession.PersonsPractice, mySession.Comments);
-
-
-		//6th drop temp table
-		Sqlite.dropTable(Constants.ConvertTempTable);
-	}
-	
-	/* used only on conversion from 0.55 to 0.56 */
-	public static int InsertOld(bool dbconOpened, string tableName, string name, string place, string date, int personsSportID, int personsSpeciallityID, int personsPractice, string comments)
-	{
-		if(! dbconOpened)
-			dbcon.Open();
-
-		dbcmd.CommandText = "INSERT INTO " + tableName + " (uniqueID, name, place, date, personsSportID, personsSpeciallityID, personsPractice, comments)" +
-			" VALUES (NULL, '"
-			+ name + "', '" + place + "', '" + date + "', " + 
-			personsSportID + ", " + personsSpeciallityID + ", " + 
-			personsPractice + ", '" + comments + "')" ;
-		dbcmd.ExecuteNonQuery();
-		int myReturn = dbcon.LastInsertRowId;
-		
-		if(! dbconOpened)
-			dbcon.Close();
-
-		return myReturn;
-	}
 }
 
 class SqliteServerSession : SqliteSession
