@@ -44,6 +44,20 @@ public class Util
 		myStringBuilder.Replace(",", ".");
 		return myStringBuilder.ToString();
 	}
+
+	//when we do a query to the server, it returns avg as "0,54" because it's latin localized
+	//if client is on english machine, need to convert this to "0.54"
+	public static string ConvertToPointIfNeeded (string myString)
+	{
+		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
+		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+		
+		StringBuilder myStringBuilder = new StringBuilder(myString);
+		if(localeInfo.NumberDecimalSeparator == ".") {
+			myStringBuilder.Replace(",", localeInfo.NumberDecimalSeparator);
+		}
+		return myStringBuilder.ToString();
+	}
 	
 	
 	//used for load from the database all numbers with correct decimal separator (locale defined)
@@ -527,6 +541,18 @@ public class Util
 
 		return 24.06 * ( tt * tf ) / (Double)tc;
 	}
+				
+	//only Lewis now
+	public static double GetPower (double tf, double bodyWeight, double extraWeightKg) 
+	{
+		//Log.WriteLine("tf: " + tf + ", bodyWeight: " + bodyWeight + ", extra: " + extraWeightKg);
+		double pw = System.Math.Sqrt ( 4.9 ) * 9.8 * (bodyWeight + extraWeightKg) *
+			System.Math.Sqrt(
+				       Convert.ToDouble(GetHeightInCentimeters(tf.ToString()))/100);
+		//Log.WriteLine("pw: " + pw);
+		return pw;
+
+	}
 
 
 	public static double GetQIndex (double tv, double tc) 
@@ -1125,57 +1151,12 @@ public class Util
 		return searchedValue;
 	}
 
-	public static string SQLBuildString (string tableName, string test, string variable,
-			int sex, string ageInterval,
-			int countryID, int sportID, int speciallityID, int levelID)
-	{
-		string strSelect = "SELECT COUNT(" + variable + "), AVG(" + variable + ")";
-		string strFrom   = " FROM " + tableName;
-		string strWhere  = " WHERE " + tableName + ".type = '" + test + "'";
-
-		string strSex = "";
-		if(sex == Constants.MaleID) 
-			strSex = " AND person.sex == '" + Constants.M + "'";
-		else if (sex == Constants.FemaleID) 
-			strSex = " AND person.sex == '" + Constants.F + "'";
-
-		string strAge = "";
-		if(ageInterval != "") {
-			strFrom += ", session";
-			string [] strFull = ageInterval.Split(new char[] {':'});
-			strAge = " AND (julianday(session.date) - julianday(person.dateBorn))/365.25 " + 
-				strFull[0] + " " + strFull[1];
-			if(strFull.Length == 4)
-				strAge += " AND (julianday(session.date) - julianday(person.dateBorn))/365.25 " + 
-					strFull[2] + " " + strFull[3];
-			strAge += " AND " + tableName + ".sessionID = session.uniqueID";
-		}
-
-		string strCountry = "";
-		if(countryID != Constants.CountryUndefinedID) 
-			strCountry = " AND person.countryID == " + countryID;
-
-		string strSport = "";
-		if(sportID != Constants.SportUndefinedID) 
-			strSport = " AND person.sportID == " + sportID;
-
-		string strSpeciallity = "";
-		if(speciallityID != Constants.SpeciallityUndefinedID) 
-			strSpeciallity = " AND person.speciallityID == " + speciallityID;
-		
-		string strLevel = "";
-		if(levelID != Constants.LevelUndefinedID) 
-			strLevel = " AND person.practice == " + levelID;
-
-		string strLast = "";
-		if(strSex.Length > 0 || strAge.Length > 0 || 
-				strCountry.Length > 0 || strSport.Length > 0 || strSpeciallity.Length > 0 || strLevel.Length > 0) {
-			strFrom += ", person";
-			strLast = " AND " + tableName + ".personID == person.UniqueID";
-		}	
-		return strSelect + strFrom + strWhere + strSex + strAge
-			+ strCountry + strSport + strSpeciallity + strLevel + strLast;
-
+	public static double ConvertFeetInchesToCm(int feet, double inches) {
+		return feet * 30.48 + inches * 2.54;
+	}
+	
+	public static double ConvertPoundsToKg(double pounds) {
+		return pounds * 0.45359237;
 	}
 
 }
